pub struct PagePoint {
pub x: f64,
pub y: f64,
}Expand description
A point in page space (points, origin bottom-left, y-up).
Fields
x: f64Horizontal position in points, from the left page edge.
y: f64Vertical position in points, from the bottom page edge (y-up).
Implementations