pub struct PageTransform { /* private fields */ }Expand description
Affine transform between pixel space of one rendered bitmap and page space of the page it was rendered from.
Obtained from RenderedPage::transform or
PdfPage::transform_for. Plain data: freely Clone/Send/Sync,
and independent of any PDFium resource.
Implementations
Sourceimpl PageTransform
impl PageTransform
Sourcepub fn pixel_width(&self) -> u32
pub fn pixel_width(&self) -> u32
Width in pixels of the bitmap this transform describes.
Sourcepub fn pixel_height(&self) -> u32
pub fn pixel_height(&self) -> u32
Height in pixels of the bitmap this transform describes.
Sourcepub fn pixel_to_page(&self, p: PixelPoint) -> PagePoint
pub fn pixel_to_page(&self, p: PixelPoint) -> PagePoint
Maps a pixel-space point to page space.
Sourcepub fn page_to_pixel(&self, p: PagePoint) -> PixelPoint
pub fn page_to_pixel(&self, p: PagePoint) -> PixelPoint
Maps a page-space point to pixel space.
Sourcepub fn pixel_rect_to_page(&self, r: PixelRect) -> PageRect
pub fn pixel_rect_to_page(&self, r: PixelRect) -> PageRect
Maps a pixel-space rectangle to a normalized page-space rectangle.
Sourcepub fn page_rect_to_pixel(&self, r: PageRect) -> PixelRect
pub fn page_rect_to_pixel(&self, r: PageRect) -> PixelRect
Maps a page-space rectangle to a pixel-space rectangle (top-left + size, with non-negative size).